@@ -122,7 +122,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = ();
 
-our $VERSION = "0.5.2";
+our $VERSION = "0.5.3";
 
 require XSLoader;
 XSLoader::load('EAV::XS', $VERSION);
@@ -226,6 +226,12 @@ I<TLD_SPECIAL>.
 
 =item *
 
+B<setup> (%options)
+
+Updates options, see description above.
+
+=item *
+
 $yes_no = B<is_email> ( $email )
 
 Validates the specified email. Returns true if the email
